import time

from cloudcontrol.server.jobs.base import BaseJob

class KillOldCliJob(BaseJob):

    """ Typically an hidden job used to kill clients who are connected/idle
        since too much time.

    Mandatory items:
     * maxcon: maximum connection time in minutes
     * maxidle: maximum idle time in minutes

    Optional items:
     * delay: delay in secondes between two checks (default 1m)
    """

    DEFAULT_DELAY = 60

    def job(self):
        maxcon = self.get('maxcon')
        assert maxcon is not None, 'maxcon is None'
        maxidle = self.get('maxidle')
        assert maxidle is not None, 'maxidle is None'
        delay = self.get('delay', self.DEFAULT_DELAY)

        while True:
            self.checkpoint()
            for client in list(self.manager.server.iterclients('cli')):
                if client.uptime > (maxcon * 60) or client.idle > (maxidle * 60):
                    self.manager.server.kill(client.login)
                    self.logger.info('Disconnected %s because of its long time'
                                     ' or idle connection', client.login)
            time.sleep(delay)
